"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DataFetcher = void 0;
const dynamic_1 = require("set-interval-async/dynamic");
const ts_log_1 = require("ts-log");
class DataFetcher {
    constructor(name, fetchFn, pollingInterval, logger = ts_log_1.dummyLogger) {
        this.name = name;
        this.pollingInterval = pollingInterval;
        this.logger = logger;
        this.isFetching = false;
        this.fetch = () => __awaiter(this, void 0, void 0, function* () {
            if (this.isFetching)
                return;
            this.isFetching = true;
            this.value = yield fetchFn();
            this.isFetching = false;
        });
    }
    initialize() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.fetch();
            this.logger.debug({ module: 'DataFetcher', instance: this.name, value: this.value }, 'Initial value fetched');
            this.pollingQueryTimer = dynamic_1.setIntervalAsync(() => __awaiter(this, void 0, void 0, function* () {
                yield this.fetch();
                this.logger.debug({ module: 'DataFetcher', instance: this.name, value: this.value }, `value fetched after ${this.pollingInterval / 1000} seconds`);
            }), this.pollingInterval);
        });
    }
    shutdown() {
        this.logger.debug(`DataFetcher: ${this.name}: shutdown`);
        return dynamic_1.clearIntervalAsync(this.pollingQueryTimer);
    }
}
exports.DataFetcher = DataFetcher;
//# sourceMappingURL=DataFetcher.js.map