"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Percentage = void 0;
const graphql_1 = require("graphql");
const REGEX = /(^100(\.0{1,2})?$)|(^([1-9]([0-9])?|0)(\.[0-9]{1,2})?$)/g;
function roundFloatFromString(value) {
    return parseFloat(parseFloat(value).toFixed(2));
}
exports.Percentage = new graphql_1.GraphQLScalarType({
    name: 'Percentage',
    description: '0-100.00',
    serialize(value) {
        const rounded = roundFloatFromString(value);
        if (rounded > 100 || rounded < 0) {
            throw new TypeError('Percentage must be a number between 0 - 100.00');
        }
        return rounded;
    },
    parseValue(value) {
        if (typeof value === 'string') {
            if (!REGEX.test(value)) {
                throw new TypeError(`Percentage requires Regex: ${REGEX}`);
            }
            return roundFloatFromString(value);
        }
        return parseFloat(value).toFixed(2);
    },
    parseLiteral(ast) {
        switch (ast.kind) {
            case graphql_1.Kind.STRING:
                if (!REGEX.test(ast.value)) {
                    throw new TypeError(`Percentage requires Regex: ${REGEX}`);
                }
                return roundFloatFromString(ast.value);
            case graphql_1.Kind.FLOAT:
                return parseFloat(ast.value).toFixed(2);
            case graphql_1.Kind.INT:
                return parseFloat(ast.value).toFixed(2);
        }
    }
});
//# sourceMappingURL=Percentage.js.map